.wp-full-overlay-sidebar {
	overflow: visible;
}

/**
 * Hide all sidebar sections by default, only show them (via JS) once the
 * preview loads and we know whether the sidebars are used in the template.
 */

.control-section.control-section-sidebar,
.customize-control-sidebar_widgets label,
.customize-control-sidebar_widgets .hide-if-js {
	/* The link in .customize-control-sidebar_widgets .hide-if-js will fail if it ever gets used. */
	display: none;
}

.customize-control-widget_form .widget-top {
	-webkit-transition: opacity 0.5s;
	transition: opacity 0.5s;
}

.customize-control-widget_form:not(.widget-rendered) .widget-top {
	opacity: 0.5;
}

.customize-control-widget_form .widget-control-save {
	display: none;
}

.customize-control-widget_form .spinner {
	visibility: hidden;
	margin-top: 0;
}

.customize-control-widget_form.previewer-loading .spinner {
	visibility: visible;
}

.customize-control-widget_form.widget-form-disabled .widget-content {
	opacity: 0.7;
	pointer-events: none;
	-moz-user-select: none;
	-webkit-user-select: none;
	-ms-user-select: none;
	user-select: none;
}

.customize-control-widget_form .widget {
	margin-bottom: 0;
}

.customize-control-widget_form.wide-widget-control .widget-inside {
	position: fixed;
	left: 299px;
	top: 25%;
	border: 1px solid rgb(229, 229, 229);
	overflow: auto;
}
.customize-control-widget_form.wide-widget-control .widget-inside > .form {
	padding: 20px;
}

.customize-control-widget_form.wide-widget-control .widget-top {
	-webkit-transition: background-color 0.4s;
	transition: background-color 0.4s;
}
.customize-control-widget_form.wide-widget-control.expanding .widget-top,
.customize-control-widget_form.wide-widget-control.expanded:not(.collapsing) .widget-top {
	background-color: rgb(227, 227, 227);
}

.widget-inside {
	padding: 1px 10px 10px 10px;
	border-top: none;
	line-height: 16px;
}

.widget-top {
	cursor: move;
}

.customize-control-widget_form.expanded a.widget-action:after {
	content: "\f142";
}

.customize-control-widget_form.wide-widget-control a.widget-action:after {
	content: "\f139";
}

.customize-control-widget_form.wide-widget-control.expanded a.widget-action:after {
	content: "\f141";
}

.widget-title-action {
	cursor: pointer;
}

.customize-control-widget_form .widget .customize-control-title {
	cursor: move;
}

.control-section.accordion-section.highlighted > .accordion-section-title,
.customize-control-widget_form.highlighted {
	outline: none;
	-webkit-box-shadow: 0 0 2px rgba(30,140,190,0.8);
	box-shadow: 0 0 2px rgba(30,140,190,0.8);
	position: relative;
	z-index: 1;
}

#widget-customizer-control-templates {
	display: none;
}

/**
* Widget reordering styles
**/

.reorder-toggle {
	float: right;
	padding: 5px 8px;
	text-decoration: none;
	cursor: pointer;
	outline: none;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
}
.reorder-toggle:focus {
	outline: 1px dotted;
}

.reorder-done,
.reordering .reorder {
	display: none;
}

.reordering .reorder-done {
	display: block;
	color: #aa0000;
}

#customize-theme-controls .reordering .add-new-widget {
	opacity: 0.2;
	pointer-events: none;
	cursor: not-allowed;
}

#customize-theme-controls .widget-reorder-nav {
	display: none;
	float: right;
	background-color: #fafafa;
}

.widget-reorder-nav span {
	position: relative;
	overflow: hidden;
	float: left;
	display: block;
	width: 33px; /* was 42px for mobile */
	height: 43px;
	color: #82878c;
	text-indent: -9999px;
	cursor: pointer;
	outline: none;
}

.widget-reorder-nav span:before {
	display: inline-block;
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
	font: normal 20px/43px 'dashicons';
	text-align: center;
	text-indent: 0;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

.widget-reorder-nav span:hover,
.widget-reorder-nav span:focus {
	color: #444;
	background: #eee;
}

.move-widget:before {
	content: '\f504';
}

.move-widget-down:before {
	content: '\f347';
}

.move-widget-up:before {
	content: '\f343';
}

#customize-theme-controls .first-widget .move-widget-up,
#customize-theme-controls .last-widget .move-widget-down {
	color: #d5d5d5;
	cursor: default;
}

#customize-theme-controls  .move-widget-area {
	display: none;
	background: #fff;
	border: 1px solid #dedede;
	border-top: none;
	cursor: auto;
}

#customize-theme-controls .reordering .move-widget-area.active {
	display: block;
}

#customize-theme-controls .move-widget-area .description {
	margin: 0;
	padding: 15px 20px;
	font-weight: 400;
}

#customize-theme-controls .widget-area-select {
	margin: 0;
	padding: 0;
	list-style: none;
}

#customize-theme-controls .widget-area-select li {
	position: relative;
	margin: 0;
	padding: 13px 15px 15px 42px;
	color: #555;
	border-top: 1px solid #eee;
	cursor: pointer;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
}

#customize-theme-controls .widget-area-select li:before {
	display: none;
	content: '\f147';
	position: absolute;
	top: 12px;
	left: 10px;
	font: normal 20px/1 'dashicons';
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

#customize-theme-controls .widget-area-select li:last-child {
	border-bottom: 1px solid #eee;
}

#customize-theme-controls .widget-area-select .selected {
	color: #fff;
	text-shadow: 0 -1px 0 rgba(0,0,0,.4);
	background: #00a0d2;
}

#customize-theme-controls .widget-area-select .selected:before {
	display: block;
}

#customize-theme-controls .move-widget-actions {
	text-align: right;
	padding: 12px;
}

#customize-theme-controls .reordering .widget-title-action {
	display: none;
}

#customize-theme-controls .reordering .widget-reorder-nav {
	display: block;
}


/**
 * Styles for new widget addition panel
 */
.wp-full-overlay-main {
	right: auto; /* this overrides a right: 0; which causes the preview to resize, I'd rather have it go off screen at the normal size. */
	width: 100%;
}

#customize-theme-controls .add-new-widget {
	cursor: pointer;
	float: right;
	margin-left: 10px;
	-webkit-transition: all 0.2s;
	transition: all 0.2s;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
	outline: none;
}

.add-new-widget:before {
	content: "\f132";
	display: inline-block;
	position: relative;
	left: -2px;
	top: -1px;
	font: normal 20px/1 'dashicons';
	vertical-align: middle;
	-webkit-transition: all 0.2s;
	transition: all 0.2s;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

body.adding-widget .add-new-widget,
body.adding-widget .add-new-widget:hover {
	background: #eee;
	border-color: #999;
	color: #32373c;
	-webkit-box-shadow: inset 0 2px 5px -3px rgba(0, 0, 0, 0.5);
	box-shadow: inset 0 2px 5px -3px rgba(0, 0, 0, 0.5);
}
body.adding-widget .add-new-widget:before {
	-webkit-transform: rotate(45deg);
	-ms-transform: rotate(45deg);
	transform: rotate(45deg);
}

#available-widgets .widget {
	position: static;
}

/* override widgets admin page rules in wp-admin/css/wp-admin.css */
#widgets-left #available-widgets .widget {
	float: none !important;
	width: auto !important;
}

#available-widgets {
	position: absolute;
	overflow: auto;
	top: 0;
	bottom: 0;
	left: -301px;
	width: 300px;
	margin: 0;
	z-index: 1;
	background: #fff !important;
	-webkit-transition: all 0.2s;
	transition: all 0.2s;
	border-right: 1px solid #dddddd;
}

#available-widgets-list {
	top: 46px;
	position: absolute;
	overflow: auto;
	bottom: 0;
	width: 100%;
}

#available-widgets-filter {
	position: fixed;
	top: 0;
	z-index: 1;
	width: 300px;
	height: 46px;
	padding: 8px 17px 7px 13px;
	background: #eee;
	border-bottom: 1px solid #e4e4e4;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
}

#available-widgets-filter input {
	padding: 5px 10px 2px 10px;
	width: 100%;
}

#available-widgets .widget-tpl {
	position: relative;
	padding: 20px 15px 20px 60px;
	border-bottom: 1px solid #e4e4e4;
	cursor: pointer;
	display: none;
}

#available-widgets .widget-tpl:hover,
#available-widgets .widget-tpl.selected {
	background: #fafafa;
}

#available-widgets .widget-top,
#available-widgets .widget-top:hover {
	border: none;
	background: transparent;
	-webkit-box-shadow: none;
	box-shadow: none;
}

#available-widgets .widget-title h4 {
	padding: 0 0 5px;
	font-size: 14px;
}

#available-widgets .widget .widget-description {
	padding: 0;
	color: #777;
}

#customize-preview {
	-webkit-transition: all 0.2s;
	transition: all 0.2s;
}

body.adding-widget #available-widgets {
	left: 0;
}

body.adding-widget .wp-full-overlay-main {
	left: 300px;
}

body.adding-widget #customize-preview {
	opacity: 0.4;
}


/**
 * Widget Icon styling
 * No plurals in naming.
 * Ordered from lowest to highest specificity.
 **/
#available-widgets .widget-title {
	position: relative;
}

#available-widgets .widget-title:before {
	content: "\f132";
	position: absolute;
	top: -3px;
	right: 100%;
	margin-right: 20px;
	width: 20px;
	height: 20px;
	color: #32373c;
	font: normal 20px/1 'dashicons';
	text-align: center;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

/* smiley */
#available-widgets [class*="easy"] .widget-title:before { content: "\f328"; top: -4px; }

/* star-filled */
#available-widgets [class*="super"] .widget-title:before,
#available-widgets [class*="like"] .widget-title:before { content: "\f155"; top: -4px; }

/* wordpress */
#available-widgets [class*="meta"] .widget-title:before { content: "\f120"; }

/* archive-box */
#available-widgets [class*="archives"] .widget-title:before { content: "\f480"; top: -4px; }

/* category */
#available-widgets [class*="categor"] .widget-title:before { content: "\f318"; top: -4px; }

/* comments */
#available-widgets [class*="comment"] .widget-title:before,
#available-widgets [class*="testimonial"] .widget-title:before,
#available-widgets [class*="chat"] .widget-title:before { content: "\f101"; }

/* post */
#available-widgets [class*="post"] .widget-title:before { content: "\f109"; }

/* admin-page */
#available-widgets [class*="page"] .widget-title:before { content: "\f105"; }

/* text */
#available-widgets [class*="text"] .widget-title:before { content: "\f478"; }

/* links */
#available-widgets [class*="link"] .widget-title:before { content: "\f103"; }

/* search */
#available-widgets [class*="search"] .widget-title:before { content: "\f179"; }

/* menu */
#available-widgets [class*="menu"] .widget-title:before,
#available-widgets [class*="nav"] .widget-title:before { content: "\f333"; }

/* tag-cloud */
#available-widgets [class*="tag"] .widget-title:before { content: "\f479"; }

/* rss */
#available-widgets [class*="rss"] .widget-title:before { content: "\f303"; top: -6px; }

/* calendar */
#available-widgets [class*="event"] .widget-title:before,
#available-widgets [class*="calendar"] .widget-title:before { content: "\f145"; top: -4px;}

/* format-image */
#available-widgets [class*="image"] .widget-title:before,
#available-widgets [class*="photo"] .widget-title:before,
#available-widgets [class*="slide"] .widget-title:before,
#available-widgets [class*="instagram"] .widget-title:before { content: "\f128"; }

/* format-gallery */
#available-widgets [class*="album"] .widget-title:before,
#available-widgets [class*="galler"] .widget-title:before { content: "\f161"; }

/* format-video */
#available-widgets [class*="video"] .widget-title:before,
#available-widgets [class*="tube"] .widget-title:before { content: "\f126"; }

/* format-audio */
#available-widgets [class*="music"] .widget-title:before,
#available-widgets [class*="radio"] .widget-title:before,
#available-widgets [class*="audio"] .widget-title:before { content: "\f127"; }

/* admin-users */
#available-widgets [class*="login"] .widget-title:before,
#available-widgets [class*="user"] .widget-title:before,
#available-widgets [class*="member"] .widget-title:before,
#available-widgets [class*="avatar"] .widget-title:before,
#available-widgets [class*="subscriber"] .widget-title:before,
#available-widgets [class*="profile"] .widget-title:before,
#available-widgets [class*="grofile"] .widget-title:before { content: "\f110"; }

/* cart */
#available-widgets [class*="commerce"] .widget-title:before,
#available-widgets [class*="shop"] .widget-title:before,
#available-widgets [class*="cart"] .widget-title:before { content: "\f174"; top: -4px; }

/* shield */
#available-widgets [class*="secur"] .widget-title:before,
#available-widgets [class*="firewall"] .widget-title:before { content: "\f332"; }

/* chart-bar */
#available-widgets [class*="analytic"] .widget-title:before,
#available-widgets [class*="stat"] .widget-title:before,
#available-widgets [class*="poll"] .widget-title:before { content: "\f185"; }

/* feedback */
#available-widgets [class*="form"] .widget-title:before { content: "\f175"; }

/* email-alt */
#available-widgets [class*="subscribe"] .widget-title:before,
#available-widgets [class*="news"] .widget-title:before,
#available-widgets [class*="contact"] .widget-title:before,
#available-widgets [class*="mail"] .widget-title:before { content: "\f466"; }

/* share */
#available-widgets [class*="share"] .widget-title:before,
#available-widgets [class*="socia"] .widget-title:before { content: "\f237"; }

/* translation */
#available-widgets [class*="lang"] .widget-title:before,
#available-widgets [class*="translat"] .widget-title:before { content: "\f326"; }

/* location-alt */
#available-widgets [class*="locat"] .widget-title:before,
#available-widgets [class*="map"] .widget-title:before { content: "\f231"; }

/* download */
#available-widgets [class*="download"] .widget-title:before { content: "\f316"; }

/* cloud */
#available-widgets [class*="weather"] .widget-title:before { content: "\f176"; top: -4px;}

/* facebook */
#available-widgets [class*="facebook"] .widget-title:before { content: "\f304"; }

/* twitter */
#available-widgets [class*="tweet"] .widget-title:before,
#available-widgets [class*="twitter"] .widget-title:before { content: "\f301"; }


@media screen and (max-height: 700px) and (min-width: 981px) {
	.customize-control {
		margin-bottom: 0;
	}
	.widget-top {
		-webkit-box-shadow: none;
		box-shadow: none;
		margin-top: -1px;
	}
	.widget-top:hover {
		position: relative;
		z-index: 1;
	}
	.last-widget {
		margin-bottom: 15px;
	}
	.widget-title h4 {
		padding: 13px 15px;
	}
	.widget-top a.widget-action:after {
		padding-top: 9px;
	}
	.widget-reorder-nav span {
		height: 39px;
	}
	.widget-reorder-nav span:before {
		line-height: 39px;
	}
	#customize-theme-controls .widget-area-select li {
		padding: 9px 15px 11px 42px;
	}
	#customize-theme-controls .widget-area-select li:before {
		top: 8px;
	}
}

@media screen and ( max-width: 640px ) {
	body.adding-widget div#available-widgets {
		top: 46px;
		left: 0;
		z-index: 10;
		width: 100%;
	}

	#available-widgets-filter {
		position: static;
		width: 100%;
		height: auto;
	}
}
