	<?php
/**
 * Template name: proposal
 */
get_header();

?>

<?php
session_start();
if($_SESSION['views'] !='2'){

echo "<script>window.location.href='/access-inspection-report/'</script>";

}
$wel = $_POST['welcome'];
?>
<?php
/*$dbuser = "ezsmscan";
$dbpass = "sdnPRr6cXpQ5sASV";
$dbname = "ezsmscan";
$dbhost = "65.182.188.219";*/
$dbuser = "ezsmscan";
$dbpass = "sdnPRr6cXQ5sA";
$dbname = "ezsmscan";
$dbhost = "207.191.234.131";
$db = mysql_connect($dbhost, $dbuser, $dbpass) or die("Unable to connect to database");
	mysql_select_db($dbname);
//echo $wel;
$queryEmail="SELECT * FROM reports where userid = '".$_SESSION['uid']."'";
					//$queryEmail="SELECT * FROM reports where userid = '1269'";
							$reult=mysql_query($queryEmail);
 $data = mysql_fetch_array($reult);
// print_r($data);?>
                    


<section id="content_wrapper_main">
    <section class="content_wrapper">
      <section class="product_top">
        <div class="proposal_top">
<div class="proposal_top_left">
Easy Server Management has completed an inspection of your IP address <?php echo $data['ip'];?>. At the time of this inspection, your server had <n> issues that require your urgent attention. If you have already taken care of critical issues, you may request a re-inspection. Click on the view report button to view the complete information.
</div>
<div class="proposal_top_right">
<form action='/reportuser/' method='post'>
<input type='hidden' name='wel2' value='<?php echo $wel; ?>'>
<input type='submit' name='view2' value='View Report'>
</form>

</div>
</div>
<div class="recommendation_services">
<div class="r_s_left">
<div class="r_s_left_content">
<div class="subscription">

  <p>Full Service Subscription Plan   </p>
  <p><a href="https://billing.easyservermanagement.com/order/?form_id=71" target="_blank"> $99 Setup and $99 per month</a>    </p>
  <p style="font-size:12px;">Sign up within a week of inspection date    </p>
  <p style="font-size:11px;">and get a $50 discount on setup fee of $99    </p>
  <p style="font-size:8px;">(your credit card will be charged $49+$99 for the first month and $99 per month) </p>
</div>
<div class="security">


<p>Security Hardening and Monitoring</p>

 
 <p> <a href="https://billing.easyservermanagement.com/order/?form_id=102" target="_blank">$99 Setup and $65 per month</a><br>
<span style="font-size:12px;">Sign up within a week of inspection date</span></p>
  

  <p style="font-size:12px;">and get a $50 discount on setup fee of $99</p> 
 <p style="font-size:8px;">(your credit card will be charged $49+$65 for the first month and $65 per month)</p></div>


</div>
<div class="r_s_left_content">
<div class="demand">

  <p>On-Demand Hourly Help   </p>
  <p> <a href="https://billing.easyservermanagement.com/order/?form_id=87" target="_blank">$65 per hour</a> </p>
  <p>We estimate <?php echo $data['hours'];?> hour(s) effort in securing your server</p>
  <p style="font-size:12px;">Sign up within a week of inspection date</p>
  <p style="font-size:11px;"> and get a $15 per hour discount    </p>
  <p style="font-size:8px;">(your credit card will be charged $50/h only)</p>
</div>
<div class="time">

  <p>One-Time Security Hardening    </p>
  <p><a href="https://billing.easyservermanagement.com/order/?form_id=89" target="_blank">$150 One-Time Service</a>  <br>
<span style="font-size:12px;">Sign up within a week of inspection date </span> </p>
  <p style="font-size:11px;">
    
    and get a $50 discount    </p>
  <p style="font-size:8px;">(your credit card will be charged $100 only) </p>
</div>

</div>

</div>
<div class="r_s_right">
<p style="font-size:14px; padding: 10px 6px; color:#F9D654;">Exclusively for you <span><?php echo $_SESSION['uname']; ?></span></p>
<p style="text-align:center; padding: 10px 0 0 0;">Join CLUB EZSM</p>
<ul>
<li>One hour support per month </li>
<li>DIY help request through forum</li>
<li>Monthly free inspections</li>
<li>10% discount on additional hrs</li>

</ul>
<h2><a href="https://billing.easyservermanagement.com/order/?form_id=101" target="_blank">$29 per month</a></h2>

</div>

</div>


<div class="recommendation_main">
<div class="recommendation_left"><img src="http://www1.ezsm.com/wp-content/uploads/2013/01/recommendation1.jpg" alt="" title="recommendation" width="313" height="82" class="aligncenter size-full wp-image-1684" /></div>
<div class="recommendation_right">

We suspect additional vulnerabilities in your server and recommend a 1000 point INTERNAL inspection.  If you buy any of the services above or membership to CLUB EZSM, internal inspection is either included or done for NO CHARGE upon request.  This is a $99 Value. If you are not purchasing any of our services above, you can <a href="https://billing.easyservermanagement.com/order/?form_id=104" target="_blank">click here</a> to purchase an INTERNAL INSPECTION for a $99 one-time charge.
</div>

</div>
        
        
        
      </section>
    </section>
        </section>
        
<!--Main Container Ends Here-->

<?php get_footer(); ?>

</div><!--wrapper ends here -->  
    

    
  