@charset "utf-8";
/* CSS Document */

body{
margin:0px;
padding:0px;
font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:normal;
}

*{margin:0px; padding:0px; list-style-type:none;}

img{border:none;}

@font-face {
				font-family: 'MyriadPro-Regular';
				src: url('fonts/myriadpro-regular.eot');
				src: url('fonts/myriadpro-regular.eot?#iefix') format('embedded-opentype'),
						 url('fonts/myriadpro-regular.woff') format('woff'),
						 url('fonts/myriadpro-regular.ttf') format('truetype'),
						 url('fonts/myriadpro-regular.svg#myriadpro-regular') format('svg');
				font-weight: normal;
				font-style: normal;
		}

#main_wrapper{
width:100%;
height:auto;
float:left;
}

/*Header Start Here*/

header{
width:100%;
height:auto;
float:left;
position:relative;
z-index:1000;
}

.header_wrapper{
width:1000px;
height:auto;
margin:auto;
}

.header_top{
width:100%;
height:auto;
float:left;
}

.company{
width:275px;
height:auto;
margin:17px 0 0 0;
float:left;
}

/*Login Area Start Here*/

.login_area{
width:496px;
height:auto;
float:right;
margin:25px 0 0 0;
}

.login_top{
width:100%;
height:auto;
float:left;
}

.login_bottom{
width:100%;
height:auto;
color:#005b84;
margin:4px 0 0 0;
float:left;
}

.login_bottom ul li{
float:left;
padding:0 4px 0 0;
}

.login_bottom ul li a{
color:#005b84;
text-decoration:none;
}

.login_top input{

border:none;
font-size:11px;
float:left;
}

.login_top input[type="text"]{
width:204px;
color:#161b7b;
background:#e0e0e0;
padding:4px 4px;
*padding-top:6px;
height:20px;
*height:18px;
}
.login_top input[type="password"]{
width:204px;
color:#161b7b;
background:#e0e0e0;
padding:4px 4px;
*padding-top:6px;
height:20px;
*height:18px;
}



.login_top input.password{
margin:0 0 0 5px;
}

.login_top input[type="submit"]{
color:#fff;
width:62px;
height:27px;
background:#005b84;
margin:0 0 0 5px;
cursor:pointer;
text-transform:uppercase;
}
.login_top input[type="submit"]:hover{
background:#036896;
}

/*Login Area Ends Here*/

/*Navigation Start Here*/

nav{
width:100%;
height:auto;
font-family: 'MyriadPro-Regular';
font-size:16px;
color:#005b84;
margin:24px 0 0 0;
float:left;
}

nav ul li{
float:left;
position:relative;

padding:0 0px 12px 0;

margin:0 68px 0 0;
*margin:0 60px 0 0;

display:block !important;
}
.menu-item-1162
{
margin-right:0px !important;

}
.menu-item-694{
margin-right:0px !important;

}
nav ul li a{
background:url(images/nav_bg.png) no-repeat right 8px ;
color:#005b84;
padding:0 18px 0 0;
text-decoration:none;
display:block;

}

nav ul li ul{
display:none;
}

nav ul li:hover ul{
display:block;
position:absolute;
top:20px;
left:0px;
background:#ecf1f4;
width:100% !important;
font-size:12px;
}

nav ul li:hover ul li{
position:relative;
border-bottom:1px solid #C2D3E3;
display:block !important;
width:100%;
padding:0px !important;
}


nav ul li:hover ul li a{
background-image:none;
padding:8px 5px;

}
nav ul li:hover ul li a:hover{
color:#313131;
}

nav ul li:hover ul li ul{
display:none;
}

nav ul li ul li:hover ul{
display:block;
position:absolute;
top:0px;
left:100%;
}

/*Navigation Ends Here*/

/*Header Ends Here*/

#about_wrapper_main{
width:100%;
height:auto;
float:left;
}

#content_wrapper_main{
width:100%;
height:auto;
float:left;
}

.content_wrapper{
width:1000px;
height:auto;
margin:auto;
}

.slogan{
width:100%;
height:auto;
float:left;
}

.slogan img{


}

.footer_nav{
width:100%;
height:auto;
float:left;
color:#005b84;
text-align:center;
margin:20px 0 0 0;
}

.footer_nav ul li{
display:inline;
padding:0 8px 0 4px;
background:url(images/divider.gif) no-repeat right 3px ;
}
#menu-item-257
{
background:none;
}
.footer_nav ul li a{
color:#005b84;
text-decoration:none;
}
.footer_nav p{
padding:5px 0 0 0;
}

.socialmedia{
width:100%;
height:auto;
margin:14px 0 0 0;
float:left;
}

.socialmedia ul{
float:right;
}
.socialmedia ul li{
height:60px;
position:relative;
margin:0 3px 0 0;
float:left;
}

.socialmedia ul li.txt_social{
padding:25px 11px 0 0;
}

.socialmedia ul li a{
width:58px;
height:62px;
background-image:url(images/socialmedia.png);
background-repeat:no-repeat;
display:block;
cursor:pointer;
}
.socialmedia ul li a span{
display:none;
}

li.ezsm a{
left:0px;
background-position:0 0;
}
li.ezsm a:hover{
left:0px;
background-position:0 -62px;
}

li.facebook a{
left:61px;
background-position:-61px 0;
}
li.facebook a:hover{
left:61px;
background-position:-61px -62px;
}

li.linkedin a{
left:122px;
background-position:-122px 0;
}
li.linkedin a:hover{
left:122px;
background-position:-122px -62px;
}



footer{
width:100%;
height:auto;
float:left;

}

.footer_wrapper{
width:1000px;
margin:auto;
}

.footer_links_wrapper{
width:100%;
background-color:#131313;
height:auto;
padding:26px 0;
float:left;

}

.footer_links{
width:1000px;
margin:auto;
}

.footer_links ul li{
padding:0 20px 0 0;
font-family: 'MyriadPro-Regular';
font-size:14px;
width:225px;
color:#fff;
float:left;

}

.footer_links ul li a{
color:#fff;
text-decoration:none;
}
.footer_links ul li a:hover{
color:#f9d654;
}
.footer_links ul li.last{
margin-right:0px;
}

/*footer links */


.footermenu li {
  
	padding:0 0 5px 18px !important; 

}

.footermenu li ul {
    display: none;
	margin:10px 0 0 0;
	font-size:12px !important; 
}




/*Product Page Start Here*/

.product_top{
width:100%;
height:auto;
float:left;
font-family: 'MyriadPro-Regular';
font-size:16px;
}

.product_rowone{
width:100%;
height:auto;
float:left;
}

.product_img{
width:397px;
height:auto;
float:left;
}
.product_img img{


border:1px solid #cfe0e8;
}

.rowone_right{
width:593px;
height:auto;
float:right;
}

.product_title{
width:571px;
height:auto;
float:left;
font-size:18px;
color:#fff;
background:#005b84;

padding:20px 0px 20px 24px;
}

.product_discription{
width:554px;
height:135px;
float:left;
background:#f9d654;

font-size:18px;
padding:15px 15px 25px 24px;
margin:9px 0 0 0;
text-align:justify;
}

.product_discription p{
font-size:16px;

}
.product_discription ul{
margin:6px 0 0 0;
padding:0px;
}

.product_discription ul li{
float:left;
margin:0 5px 0 0;

font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:bold;
}
.product_discription ul li a{
color:#fff;
display:block;
padding:8px;
text-decoration:none;
background:#005b84;


}
.product_discription ul li a:hover{
background:#036896;
}



.product_discription_vps{
width:554px;
height:162px;
float:left;
background:#f9d654;

font-size:18px;
padding:15px 15px 25px 24px;
margin:9px 0 0 0;
text-align:justify;
}

.product_discription_vps p{
font-size:14px;

}
.product_discription_vps ul{
margin:12px 0 0 0;
padding:0px;
}

.product_discription_vps ul li{
float:left;
margin:0 5px 0 0;

font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:bold;
}
.product_discription_vps ul li a{
color:#fff;
display:block;
padding:8px;
text-decoration:none;
background:#005b84;


}
.product_discription_vps ul li a:hover{
background:#036896;
}
.product_discription_vm{
width:554px;
height:162px;
float:left;
background:#f9d654;

font-size:18px;
padding:15px 15px 25px 24px;
margin:9px 0 0 0;
text-align:justify;
}
.product_discription_vps ul li.drop_down_blue{
    background-color: #005B84;
    color: #000000;

    padding: 7px;

	}
.product_discription_vps ul li .drop_down_exchange {
    background: none repeat scroll 0 0 #005B84;
    border: medium none;
    color: #fff;
    font-size: 12px;
    font-weight: bold;
    width: 208px;
	font-family: Arial,Helvetica,sans-serif;
}

.product_discription_vm ul li.drop_down_blue{
    background-color: #005B84;
    color: #000000;

    padding: 7px;

	}
.product_discription_vm ul li .drop_down_exchange {
    background: none repeat scroll 0 0 #005B84;
    border: medium none;
    color: #fff;
    font-size: 12px;
    font-weight: bold;
    width: 208px;
	font-family: Arial,Helvetica,sans-serif;
}

.product_discription_vm p{
font-size:16px;

}
.product_discription_vm ul{
margin:12px 0 0 0;
padding:0px;
}

.product_discription_vm ul li{
float:left;
margin:0 5px 0 0;

font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:bold;
}
.product_discription_vm ul li a{
color:#fff;
display:block;
padding:8px;
text-decoration:none;
background:#005b84;
}
.product_discription_vm ul li a:hover{
background:#036896;
}



.product_discription_analysis{
width:554px;
height:196px;
float:left;
background:#f9d654;
font-size:18px;
padding:15px 15px 25px 24px;
margin:9px 0 0 0;
text-align:justify;
}

.product_discription_analysis p{
font-size:14px;

}

.product_discription_analysis ul{
margin:6px 0 0 0;
padding:0px;
}

.product_discription_analysis ul li{
float:left;
margin:0 5px 0 0;
font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:bold;
}
.product_discription_analysis ul li a{
color:#fff;
display:block;
padding:8px;
text-decoration:none;
background:#005b84;
}
.product_discription_analysis ul li a:hover{
background:#036896;
}

.product_discription_analysis ul li .drop_down_exchange {
    background: none repeat scroll 0 0 #005B84;
    border: medium none;
    color: #fff;
    font-size: 12px;
    font-weight: bold;
    width: 208px;
	font-family: Arial,Helvetica,sans-serif;
}

.product_discription_analysis ul li.drop_down_blue {
    background-color: #005B84;
    color: #000000;
    padding: 7px;
}

.product_discription_moniter{
width:554px;
height:196px;
float:left;
background:#f9d654;
font-size:18px;
padding:15px 15px 25px 24px;
margin:9px 0 0 0;
text-align:justify;
}

.product_discription_moniter p{
font-size:14px;
}

.product_discription_moniter ul{
margin:12px 0 0 0;
padding:0px;
}

.product_discription_moniter ul li{
float:left;
margin:0 5px 0 0;

font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:bold;
}
.product_discription_moniter ul li a{
color:#fff;
display:block;
padding:8px;
text-decoration:none;
background:#005b84;
}
.product_discription_moniter ul li a:hover{
background:#036896;
}
.product_discription_plesk{
width:554px;
height:135px;
float:left;
background:#f9d654;

font-size:18px;
padding:15px 15px 25px 24px;
margin:9px 0 0 0;
text-align:justify;
}
.product_discription_plesk p{
font-size:15px;

}

.product_discription_plesk ul{
margin:16px 0 0 0;
padding:0px;
}

.product_discription_plesk ul li{
float:left;
margin:0 5px 0 0;

font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:bold;
}
.product_discription_plesk ul li a{
color:#fff;
display:block;
padding:8px;
text-decoration:none;
background:#005b84;


}
.product_discription_plesk ul li a:hover{
background:#036896;
}




.product_discription_cloud{
width:554px;
height:135px;
float:left;
background:#f9d654;


font-size:18px;
padding:15px 15px 25px 24px;
margin:9px 0 0 0;
text-align:justify;
}
.product_discription_cloud p{
font-size:14px;

}

.product_discription_cloud ul{
margin:16px 0 0 0;
padding:0px;
}

.product_discription_cloud ul li{
float:left;
margin:0 5px 0 0;

font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:bold;
}
.product_discription_cloud ul li a{
color:#fff;
display:block;
padding:8px;
text-decoration:none;
background:#005b84;


}
.product_discription_cloud ul li a:hover{
background:#036896;
}







.product_discription_exchange{
width:554px;
height:135px;
float:left;
background:#f9d654;


font-size:18px;
padding:15px 15px 25px 24px;
margin:9px 0 0 0;
text-align:justify;
}
.product_discription_exchange p{
font-size:14px;

}

.product_discription_exchange ul{
margin:6px 0 0 0;
padding:0px;
}

.product_discription_exchange ul li{
float:left;
margin:0 5px 0 0;
font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:bold;
}
.product_discription_exchange ul li.drop_down_blue{
    background-color: #005B84;
    color: #000000;

    padding: 7px;

	}
.product_discription_exchange ul li .drop_down_exchange {
    background: none repeat scroll 0 0 #005B84;
    border: medium none;
    color: #fff;
    font-size: 12px;
    font-weight: bold;
    width: 208px;
	font-family: Arial,Helvetica,sans-serif;
}

.product_discription_exchange ul li .drop_down_exchange option
{

}
.product_discription_exchange ul li a{
color:#fff;
display:block;
padding:8px;
text-decoration:none;
background:#005b84;

}
.product_discription_exchange ul li a:hover{
background:#036896;
}


.product_rowtwo{
width:100%;
height:auto;
float:left;
margin:9px 0 0 0;
}
.product_rowtwo_exchange{
width:100%;
height:auto;
float:left;
margin:9px 0 0 0;
font-family: 'MyriadPro-Regular';
font-size:14px;
}

.product_exchange_inner {
    background: none repeat scroll 0 0 #D3D3D3;

    color: #000;
    float: left;
    height: 488px;
    padding: 0 20px 0 0;
    width: 369px;

}
.product_exchange_inner h1
{
font-size:18px;
font-weight:normal;
color:#000;
padding:20px 0px 10px 20px;
font-family: Arial,Helvetica,sans-serif;
}


.product_exchange_inner ul{
margin:0 0 0 20px;
}

.product_exchange_inner ul li{
background:url(images/square.png) no-repeat 0 4px;
padding:0 0 15px 15px;
text-align: justify;
}

.exchange_inner ul
{
padding:0px;
}

.exchange_inner ul li{
background-image:none;
float:left;
padding:0px;
font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:bold;
margin:0 5px 0 0;
}
.exchange_inner ul li a {
    background: none repeat scroll 0 0 #005B84;


    color: #FFFFFF;
    display: block;
    padding: 8px;
    text-decoration: none;
}

.exchange_inner ul li a:hover
{
  background: none repeat scroll 0 0 #036896;
}
.product_rowtwo_inspection{
width:100%;
height:auto;
float:left;
margin:9px 0 0 0;
font-family: 'MyriadPro-Regular';
font-size:14px;
float: left;
    height: auto;
    width: 100%;
}

.product_inspection_inner {
    background: none repeat scroll 0 0 #3EC4A3;

    color: #fff;
    float: left;
    height: 260px;

    width: 496px;

}

.product_inspection_inner h1
{
font-size:18px;
font-weight:normal;
color:#fff;
padding:20px 0px 10px 20px;
font-family: Arial,Helvetica,sans-serif;
}.product_inspection_inner ul{
margin:0 0 0 20px;
}

.product_inspection_inner ul li{
background:url(images/white_square.png) no-repeat 0 4px;
padding:0 20px 15px 15px;
text-align: justify;
}


.product_detail_inspection_inner
{
width:496px;
height:260px;
background:#F9D654;

color:#313131;
text-align:justify;
float:right;
}
.product_detail_inspection_inner p{
padding:0 20px;

}

.product_detail_inspection_inner ul{
margin:0 20px;
}

.product_detail_inspection_inner ul li{
background:url(images/square.png) no-repeat 0 4px;
padding:0 0 15px 15px;
text-align: justify;
}
.product_detail_inspection_inner h1
{
font-size:18px;
font-weight:normal;
color:#313131;
padding:20px 0px 10px 20px;
font-family: Arial,Helvetica,sans-serif;
}



.product_detail_exchange_inner
{
width:604px;
height:488px;
background:#005B84;

color:#fff;
text-align:justify;
float:right;
}
.product_detail_exchange_inner p{
padding:0 20px;

}
.product_detail_exchange_inner h1
{
font-size:18px;
font-weight:normal;
color:#fff;
padding:20px 0px 10px 20px;
font-family: Arial,Helvetica,sans-serif;
}


.product_detail_exchange_inner ul{
margin:0 20px;
}

.product_detail_exchange_inner ul li{
background:url(images/white_square.png) no-repeat 0 4px;
padding:0 0 15px 15px;
text-align: justify;
}
.product_detail_exchange_inner .exchange_sub_inner
{
margin:0;

}
.product_detail_exchange_inner .exchange_sub_inner ul
{
padding:0px;
}

.product_detail_exchange_inner .exchange_sub_inner ul li{
background-image:none;
float:left;
padding:0px;
font-family:Arial, Helvetica, sans-serif;
font-size:12px;
font-weight:bold;
margin:0 5px 0 0;
}
.product_detail_exchange_inner .exchange_sub_inner ul li a {
    background: none repeat scroll 0 0 #F9D654;


    color: #000;
    display: block;
    padding: 8px;
    text-decoration: none;
}
.product_detail_exchange_inner .exchange_sub_inner ul li a:hover
{
 background: none repeat scroll 0 0 #E4C44C;

}
.single_inner_heading
{
font-size:16px;
padding:0 0 10px 0px;
text-align:center;
}
.netmonitor_detail{
width:369px;
height:275px;
background:#F9D654;


color:#000;
text-align:justify;
float:right;
}


.netmonitor_detail p{
padding:24px;

}

.netmonitor_detail_analysis{
width:369px;
height:272px;
background:#F9D654;
color:#000;
text-align:justify;
float:right;
}


.netmonitor_detail_analysis p{
padding:24px;

}

.netmonitor_faq{
width:604px;
padding:0 20px 0 0;
background:#34a0d1;

color:#fff;
height:275px;
float:left;
}

.netmonitor_faq p
{
padding:0 0 0 15px;
text-align:justify;
}
.netmonitor_faq ul{
margin:20px 0 0 20px;
padding:0px;
}

.netmonitor_faq ul li{
display:block;
padding:4px 0 5px 30px;
background:url(images/man.gif) no-repeat 0 4px;
}

.netmonitor_faq ul li a{
color:#fff;
text-decoration:none;
}

.netmonitor_faq ul li a:hover{
color:#005b84;
}

.product_detail_window{
width:369px;
height:252px;
background:#F9D654;
color:#000;
text-align:justify;
float:right;
}


.product_detail_window p{
padding:24px;

}

.product_faq_window{
width:604px;
padding:0 20px 0 0;
background:#34a0d1;

color:#fff;
height:252px;
float:left;
}

.product_faq_window p
{
padding:0 0 0 15px;
text-align:justify;
}
.product_faq_window ul{
margin:20px 0 0 20px;
padding:0px;
}

.product_faq_window ul li{
display:block;
padding:4px 0 5px 30px;
background:url(images/man.gif) no-repeat 0 4px;
}

.product_faq_window ul li a{
color:#fff;
text-decoration:none;
}

.product_faq_window ul li a:hover{
color:#005b84;
}

.product_detail_linux{
width:369px;
height:282px;
background:#F9D654;
color:#000;
text-align:justify;
float:right;
}


.product_detail_linux p{
padding:24px;

}

.product_faq_linux{
width:604px;
padding:0 20px 0 0;
background:#34a0d1;

color:#fff;
height:282px;
float:left;
}

.product_faq_linux p
{
padding:0 0 0 15px;
text-align:justify;
}
.product_faq_linux ul{
margin:20px 0 0 20px;
padding:0px;
}

.product_faq_linux ul li{
display:block;
padding:4px 0 5px 30px;
background:url(images/man.gif) no-repeat 0 4px;
}

.product_faq_linux ul li a{
color:#fff;
text-decoration:none;
}

.product_faq_linux ul li a:hover{
color:#005b84;
}
.product_detail_jboss{
width:369px;
height:232px;
background:#F9D654;


color:#000;
text-align:justify;
float:right;
}


.product_detail_jboss p{
padding:24px;

}

.product_faq_jboss{
width:604px;
padding:0 20px 0 0;
background:#34a0d1;

color:#fff;
height:232px;
float:left;
}

.product_faq_jboss p
{
padding:0 0 0 15px;
text-align:justify;
}
.product_faq_jboss ul{
margin:20px 0 0 20px;
padding:0px;
}

.product_faq_jboss ul li{
display:block;
padding:4px 0 5px 30px;
background:url(images/man.gif) no-repeat 0 4px;
}

.product_faq_jboss ul li a{
color:#fff;
text-decoration:none;
}

.product_faq_jboss ul li a:hover{
color:#005b84;
}

.netmonitor_faq_analysis{
width:604px;
padding:0 20px 0 0;
background:#34a0d1;

color:#fff;
height:272px;
float:left;
}

.netmonitor_faq_analysis p
{
padding:0 0 0 15px;
text-align:justify;
}
.netmonitor_faq_analysis ul{
margin:20px 0 0 20px;
padding:0px;
}

.netmonitor_faq_analysis ul li{
display:block;
padding:4px 0 5px 30px;
background:url(images/man.gif) no-repeat 0 4px;
}

.netmonitor_faq_analysis ul li a{
color:#fff;
text-decoration:none;
}

.netmonitor_faq_analysis ul li a:hover{
color:#005b84;
}



.product_external_inspection1{
width:604px;
padding:0 20px 0 0;
background:#F9D654;
color:#000;
height:225px;
float:left;
}
.product_external_inspection1 h1
{
font-size: 55px;
    margin: 7px 0;
    text-align: center;
}
.product_external_inspection1 p
{
padding:0 0 0 15px;
text-align:justify;
}

.product_external_inspection1 h1 a{
color:#fff;
text-decoration:none;
}

.product_external_inspection1 h1 a:hover{
color:#005b84;
}

.product_external_inspection2{
width:369px;
height:225px;
background:#3EC4A3;
color:#fff;
text-align:justify;
float:right;
}
.product_external_inspection2 h2
{
 font-size: 28px;
    margin: 7px 20px;
    text-align: center;
}
.product_external_inspection2 h2 a{
color:#fff;
text-decoration:underline;
font-weight:bold;
}

.product_external_inspection2 h2 a:hover{

text-decoration:underline;
}
.product_external_inspection2 p{
font-size: 24px;
    margin: 2px 20px;
    text-align: center;
}
.product_external_inspectionrow
{
margin:46px 0;
}

.product_faq{
width:604px;
padding:0 20px 0 0;
background:#34a0d1;

color:#fff;
height:225px;
float:left;
}

.product_faq p
{
padding:0 0 0 15px;
text-align:justify;
}
.product_faq ul{
margin:20px 0 0 20px;
padding:0px;
}

.product_faq ul li{
display:block;
padding:4px 0 5px 30px;
background:url(images/man.gif) no-repeat 0 4px;
}

.product_faq ul li a{
color:#fff;
text-decoration:none;
}

.product_faq ul li a:hover{
color:#005b84;
}

.product_faq_device{
width:604px;
padding:0 20px 0 0;
background:#34a0d1;

color:#fff;
height:454px;
float:left;
}

.product_faq_device p
{
padding:0 0 0 15px;
text-align:justify;
}
.product_faq_device ul{
margin:20px 0 0 20px;
padding:0px;
}

.product_faq_device ul li{
display:block;
padding:4px 0 5px 30px;
background:url(images/man.gif) no-repeat 0 4px;
}

.product_faq_device ul li a{
color:#fff;
text-decoration:none;
}

.product_faq_device ul li a:hover{
color:#005b84;
}
.product_faq_joomla{
width:604px;
padding:0 20px 0 0;
background:#34a0d1;


color:#fff;
height:236px;
float:left;
}

.product_faq_joomla p
{
padding:0 0 0 15px;
text-align:justify;
}
.product_faq_joomla ul{
margin:20px 0 0 20px;
padding:0px;
}

.product_faq_joomla ul li{
display:block;
padding:4px 0 5px 30px;
background:url(images/man.gif) no-repeat 0 4px;
}

.product_faq_joomla ul li a{
color:#fff;
text-decoration:none;
}

.product_faq_joomla ul li a:hover{
color:#005b84;
}

.product_faq_cloud{
width:604px;
padding:0 20px 0 0;
background:#34a0d1;


color:#fff;
height:272px;
float:left;
}

.product_faq_cloud p
{
padding:0 0 0 15px;
text-align:justify;
}
.product_faq_cloud ul{
margin:20px 0 0 20px;
padding:0px;
}

.product_faq_cloud ul li{
display:block;
padding:4px 0 5px 30px;
background:url(images/man.gif) no-repeat 0 4px;
}

.product_faq_cloud ul li a{
color:#fff;
text-decoration:none;
}

.product_faq_cloud ul li a:hover{
color:#005b84;
}

.product_faq_exchange{
width:604px;
padding:0 20px 0 0;
background:#34a0d1;


color:#fff;
height:280px;
float:left;
}

.product_faq_exchange p
{
padding:0 0 0 15px;
text-align:justify;
}
.product_faq_exchange ul{
margin:20px 0 0 20px;
padding:0px;
}

.product_faq_exchange li{
display:block;
padding:4px 0 5px 30px;
background:url(images/man.gif) no-repeat 0 4px;
}

.product_faq_exchange ul li a{
color:#fff;
text-decoration:none;
}

.product_faq_exchange ul li a:hover{
color:#005b84;
}
.product_detail{
width:369px;
height:225px;
background:#3ec4a3;


color:#fff;
text-align:justify;
float:right;
}
.product_detail p{
padding:24px;

}
.product_detail_joomla{
width:369px;
height:236px;
background:#3ec4a3;


color:#fff;
text-align:justify;
float:right;
}
.product_detail_joomla p{
padding:24px;

}
.product_detail_device{
width:369px;
height:454px;
background:#3ec4a3;


color:#fff;
text-align:justify;
float:right;
}
.product_detail_device p{
padding:24px;

}
.product_detail_cloud{
width:369px;
height:272px;
background:#3ec4a3;


color:#fff;
text-align:justify;
float:right;
}
.product_detail_cloud p{
padding:24px;

}
.product_detail_exchange{
width:369px;
height:280px;
background:#3ec4a3;


color:#fff;
text-align:justify;
float:right;
}
.product_detail_exchange p{
padding:24px;

}
.product_rowtwo_servers
{
width:100%;
height:auto;
float:left;
}

.product_rowtwo_servers li{
margin:9px 9px 0 0;
padding:0px;

float:left;
}
.product_rowtwo_servers li span{
font-size:10px;
}
.product_rowtwo_servers li.last{
 margin: 9px 0 0 -2px;
    width: 604px;

}

.product_rowtwo_servers li a{
text-decoration:none;
padding:20px;
display:block;


color:#fff;
 text-align: center;
}


.product_rowtwo_servers li a.yellow{
background:#f9d654;
color:#313131;

}

.product_rowtwo_servers li a.blue{
background:#005b84;
width:349px;
}

.product_rowtwo_free
{
width:100%;
height:auto;
float:left;
}
.product_rowtwo_free li{
margin:9px 9px 0 0;
padding:0px;
width: 496px;
float:left;
}
.product_rowtwo_free li span{
font-size:10px;
}
.product_rowtwo_free li.last{
 margin: 9px 0 0 -2px;
 

}

.product_rowtwo_free li a{
text-decoration:none;
padding:20px;
display:block;
color:#313131;
 text-align: center;
 font-family: 'MyriadPro-Regular';
font-size: 16px;
}


.product_rowtwo_free li a:hover
{
text-decoration:underline;
}

.product_rowthree{
width:100%;
height:auto;
float:left;
}

.product_rowthree li{
margin:9px 9px 0 0;
padding:0px;
width:327px;
float:left;
}
.product_rowthree li span{
font-size:10px;
}
.product_rowthree li.last{
margin:9px 0px 0 1px;

}

.product_rowthree li a{
text-decoration:none;
padding:20px;
display:block;
color:#fff;
 text-align: center;
}

.product_rowthree li a:hover{
text-decoration:underline;
}

.product_rowthree li a.yellow{
background:#f9d654;
color:#313131;
}

.product_rowthree li a.green{
background:#3ec4a3;
}

.product_rowthree li a.grey{
background:#d3d3d3;
color:#313131;
}

.product_rowthree li a.blue{
background:#005b84;
}

.product_rowthree li a.bluewindow
{
background:#005b84;
padding: 9px 3px 12px 3px;
    text-align: center;
}

.product_rowthree li a.skyblue{
background:#43b3e5;
}
.product_rowthree li a.skybluelinux{
background:#43b3e5;
padding: 9px 3px 12px 3px;
    text-align: center;
}
.heading{
width:100%;
height:auto;
float:left;
text-align:center;
font-family:Arial, Helvetica, sans-serif;
font-size:18px;
padding:20px 0 0 0;
color:#000;
}
.customers_wrapper_main_access{
    background: none repeat scroll 0 0 #005B84;
    float: left;
    font-family: Arial,Helvetica,sans-serif;
    height: auto;
    margin: 18px 0 0;
    padding: 11px 0;
    width: 100%;
}
.customers_wrapper_main{
width:100%;
height:auto;
float:left;
background:#d3d3d3;
font-family:Arial, Helvetica, sans-serif;
margin:18px 0 0 0;
padding:11px 0;
}

.customers_wrapper{
width:1000px;
height:auto;
margin:auto;
}
.customers_wrapper #subscription
{

}
.customers_wrapper #subscription th.Plans{
padding:5px;
background-color:#fff;
width:75px;
}
.customers_wrapper #subscription th{
padding:5px;
background-color:#fff;
}
.customers_wrapper #subscription td{
text-align:center;
background-color:#fff;
padding:5px;
height:30px;
}
.customers_wrapper #subscription td.Plans a
{
background: none repeat scroll 0 0 #005B84;
    color: #FFFFFF;
    display: block;
    padding: 8px;
    text-decoration: none;
}
.customers_wrapper #subscription td.Plans{
text-align:center;
background-color:#fff;
padding:5px;
width:75px;
}




.customers_wrapper p
{
padding:0px 10px 10px 10px;
text-align:justify;
line-height: 18px;
}

.customers_wrapper_main ul li
{
background:url(images/square.png) no-repeat 0 4px;
padding:0 0 15px 15px;
}
.customers_wrapper_main ul{
margin:0 0 0 10px;
}
.customers_left{
width:649px;
height:auto;
float:left;
margin:0 0 0 9px;
}
.customers_left h1{
font-size:16px;
}

.customers_left ul{
margin:20px 0 0 0;
}

.customers_left ul li{
background:url(images/square.png) no-repeat 0 4px;
padding:0 0 15px 15px;
text-align: justify;
}

.customers_left a
{
 color: #005B84;
    font-weight: bold;
    text-decoration: none;
}
.customers_left a:hover
{
text-decoration:underline;

}
.customers_right{
width:300px;
height:auto;
float:right;
margin:39px 9px 0 0;
background:#e0e0e0;
padding:10px 0;
}

.title{
width:290px;
height:auto;
float:left;
font-size:16px;
padding:0 0 0 10px;
}

.monitor{
width:298px;
float:left;
margin:10px 0 0 1px;
background:#3ec4a3;


padding:10px 0;
}
.monitor ul{
padding:0px;
width:250px;
margin:auto;
}

.monitor ul li{
width:125px;
float:left;
padding:0 0 5px 0;
color:#fff;
background-image:none;
}

.services{
width:100%;
height:auto;
margin:19px 0 0 0;
font-size:14px;
float:left;
}

.services ul{
margin:0px 0 0 10px;
padding:0px;
}

.services ul li{
display:block;
margin:0px;
padding:0 0 15px 20px;
background:url(images/arrow.png) no-repeat 0 5px;
text-align: justify;
}

.services ul li a{
color:#000;
text-decoration:none;
}

.services ul li a:hover{
color:#2f957c;
}

.secure_wrapper_main{
width:100%;
height:auto;
background:#f9d654;
float:left;
}

.heading2{
width:100%;
height:auto;
float:left;
text-align:center;
font-family:Arial, Helvetica, sans-serif;
font-size:18px;
padding:20px 0;
color:#005b84;
}

.secure_wrapper{
width:1000px;
padding:20px 0 20px 0;
overflow:hidden;
margin:auto;
}

.secure_left{
width:589px;
height:auto;
float:left;
margin:27px 0 0 31px;
}

.secure_left ul li{
display:block;
margin:0px;
padding:0 0 15px 20px;
background:url(images/bullet.png) no-repeat 0 3px;
text-align: justify;
}

.secure_right{
width:339px;
height:auto;
float:right;
}

.secure_one_cloud {
width:298px;
height:auto;
background:#3ec4a3;
padding:20px;


color:#fff;
float:left;
}


.secure_one_cloud  ul{
padding:0px;
width: 356px;
margin:5px 0 0 0;

}

.secure_one_cloud ul li{
width:176px;
float:left;
padding:3px 0;
color:#fff;
background-image:none;
}



.secure_one{
width:298px;
height:auto;
background:#3ec4a3;
padding:20px;


color:#fff;
float:left;
}

.secure_one h1, .secure_two h1, .secure_three h1, .secure_one_cloud h1{
font-size:18px;
font-weight:normal;
}

.secure_one ul, .secure_two ul{
margin:5px 0 0 0;
}
.secure_one ul li, .secure_two ul li{
padding:3px 0;
}

.secure_two{
width:298px;
height:auto;
background:#43b3e5;
padding:20px;


margin:9px 0 0 0;
color:#fff;
float:left;
}
.secure_three{
width:298px;
height:auto;
background:#005b84;
padding:20px;


text-align:center;
margin:9px 0 0 0;
color:#fff;
float:left;
}

.secure_three p{
margin:20px 0 0 0;
display:block;
}

.secure_three p a.buynow{
    background: none repeat scroll 0 0 #F9D654;
    color: #000000;
    font-weight: bold;
    padding: 5px 15px;
    text-decoration: none;
}
.secure_three p a:hover.buynow{
background:#e4c44c;
}

.secure_three h1 a{
color:#fff;
text-decoration:none;
}

.secure_three h1 a:hover{
color:#f9d654;
text-decoration:none;
}

.print{
width:100%;
height:auto;
float:left;
text-align: justify;
margin: 9px 0 0 0;
}
.print p{
padding:5px 0;
}

.edit-link
{
display:none;	
}

/*Product Page Start Here*/
.entry-header
{
margin:16px 0 0 0;
}
.innerpage_title
{
margin:auto;
width:1000px;

}
.innerpage_title h1
{

 text-align: center;
color:#fff;
background-color:#005B84;
padding:20px;
display:block;
font-family:'MyriadPro-Regular';
font-size:18px;
font-weight: normal;
}
.innerpage_title_inspection h1
{
  background-color: #005B84;
    color: #FFFFFF;
    display: block;
    font-family: arial,helvetica,serif;
    font-size: 52px;
    font-weight: normal;
    padding: 10px 50px;
    text-align: center;
}

.about_rowthree li{
margin:9px 9px 0 0;
padding:20px;
width:287px;
 font-size: 16px;
    height: 75px;
	font-family:'MyriadPro-Regular';
float:left;


color:#fff;
}
.about_rowthree li.last{
margin:9px 0px 0 1px;

}


.about_rowthree li.yellow{
background:#f9d654;
color:#313131;
}

.about_rowthree li.green{
background:#3ec4a3;
}

.about_rowthree li.grey{
background:#d3d3d3;
color:#313131;
}

.about_rowthree li.blue{
background:#005b84;
}

.about_rowthree li.skyblue{
background:#43b3e5;
}

.blue p
{
color:#fff;
}
.skyblue p
{

color:#fff;
}

.skyblue a
{
text-decoration:none;
color:#fff;
}
.skyblue a:hover
{
text-decoration:underline;
color:#fff;
}
/*services page START HERE */

#services_page
{
float: left;
    width: 1000px;
	position:relative;
	z-index:2;
}
#services_page a
{
text-decoration:underline;
color:#fff;
}
#services_page a:hover
{
text-decoration:underline;
color:#fff;
}
#services_article
{
float: left;
    margin: 0;
    width: 1000px;
	margin:0 0 9px 0;
}
.big_box
{
float:left;
margin:0 9px 0 0;
width:327px;
}
.small_box
{
float:left;
margin:0 9px 0 0;
width:159px;
}
.big_box_last
{
float:right !important;
width:327px;
}
.small_box_last
{
float:right;
width:159px;
}


#services_article .box{ width:327px; background:#43b3e5; float:left; margin:0 9px 0px 0; min-height:145px; }
.lin-win{ width:96px; float:left; margin:15px 17px 0 37px; height:123px; }
.win-win
{
	float: right;
    margin: 0;
    position: relative;
    right: 100px;
    top: 31px;

	}

	
#services_article p{ font-family:"MyriadPro-Regular"; font-size: 14px; color:#FFF; text-align:center; font-style:normal;padding:40px 0 0 0;}  
#services_article p span{ font-size:20px;}

.ch_element
{
min-height:145px;

}

#services_article .box1{ width:327px; background:#d1d1d1; float:left; margin:0 9px 0px 0; min-height:145px; }
.cloud{ width:141px; float:left; margin:9px 13px 0 20px; height:133px; }
#services_article .box1 p{ font-family:"MyriadPro-Regular"; font-size: 14px; color:#464646; text-align:left; font-style:normal;padding:80px 0 0 0;}  



#services_article .small-box{ width:159px; float:left; margin:0 9px 0px 0; min-height:145px; background:#3ec4a3; }
#services_article .small-box p{font-family:"MyriadPro-Regular"; font-size: 14px; color:#FFF; text-align:left; font-style:normal;padding:40px 0 10px 17px;}  
.sign{ width:87px; float:left; margin:0 0 0 17px; height:27px; background:url(images/sign-up.jpg) no-repeat; }
.sign:hover{ background-position:center -27px;}  
#services_article .small-box1{ width:159px; float:left; margin:0; min-height:145px; background:url(images/ezsm.jpg) no-repeat; }
#services_article .small-box1 p{font-family:"MyriadPro-Regular"; font-size: 12px; color:#FFF; text-align:left; font-style:normal;padding:105px 0 0 2px;} 
#services_article .box3{ width:327px; background:#3ec4a3; float:left; margin:0 9px 0px 0; min-height:145px; }
.win-lin{ width:86px; float:left; margin:9px 13px 0 20px; height:52px; }
#services_article .box3 p{ width:260px; font-family:"MyriadPro-Regular"; font-size:17px; color:#fff; text-align:left; font-style:normal;padding:40px 0 0 69px; *padding:0px 0 0 69px; *margin-top:-10px;}



.box3 p img{  float: right; margin: 0;position: relative; right: 100px; top: -6px;}  



#services_article .box4{ width:327px; background:#005b84; float:left; margin:0 9px 0px 0; min-height:145px; }
.c-penel{ width:130px; float:left; margin:43px 10px 0 20px; height:59px; }
.box4 p{ font-family:"MyriadPro-Regular"; font-size: 14px; color:#fff; text-align:left; font-style:normal;padding:25px 0 0 161px;}  

#services_article .small-box3{ width:159px; float:left; margin:0 9px 0px 0; min-height:145px; background:#43b3e5; }
#services_article .small-box3 p{font-family:"MyriadPro-Regular"; font-size: 14px; color:#FFF; text-align:center; font-style:normal;}  

#services_article .small-box4{ width:159px; float:left; margin:0 0 9px 0; min-height:145px; background:#f9d654; }

.money{ width: 53px; float:left; margin:5px 0 0 45px; height:60px;}
#services_article .small-box4 p{font-family:"MyriadPro-Regular"; font-size: 14px; color:#525047; text-align:center; font-style:normal;padding:0;} 


#services_article .small-box5{ width:159px; float:left; margin:0 9px 0px 0; min-height:145px; background:#005b84; }

.cloud-server{ width: 111px; float:left; margin:10px 0 0 25px; height:85px;}
#services_article .small-box5 p{font-family:"MyriadPro-Regular"; font-size: 14px; color:#fff; text-align:center; font-style:normal;padding:0;} 

#services_article .small-box6{ width:159px; float:left; margin:0 9px 0px 0; min-height:145px; background:#43b3e5; }

.check{ width: 133px; float:left; margin:8px 0 0 19px; height:89px;}
#services_article .small-box6 p{font-family:"MyriadPro-Regular"; font-size: 15px; color:#fff; text-align:left; font-style:normal;padding:0 0 0 19px; margin:-18px 0 0; float:left;} 

#services_article .small-box7{ width:159px; float:left; margin:0 9px 0px 0; min-height:145px; background:#f9d654; }

.share{ width: 54px; float:left; margin:20px 0 0 20px; height:61px;}
#services_article .small-box7 p{font-family:"MyriadPro-Regular"; font-size:14px; color:#525047; text-align:left; font-style:normal;padding:10px 0 0 20px;}  


#services_article .box5{ width:327px; background:#cd3f3f; float:left; margin:0 0 9px 0; min-height:145px; }

.box5 p{ width:auto; font-family:"MyriadPro-Regular"; font-size:14px; color:#fff; text-align:center; font-style:normal;padding:27px 0 0 30px;}

.box5 p span{ font-size:18px;}
.box5 p span.size{ font-size:22px!important;}
.box5 p span.color{color:#f9d654!important; font-size:22px}

#services_article .small-box8{ width:159px; float:left; margin:0 9px 0px 0; min-height:145px; background:#d1d1d1; }

.magento{ width: 142px; float:left; margin:0; height:122px;}


/*Hover CSS start here*/
.ch_hover
{
float:left; 
margin:0 7px 9px 0; 
min-height:145px; 

}

#services_article .contenthover{ width:327px; background:#242424; float:left; margin:18px 7px 9px 0; min-height:145px; }

#services_article .contenthover p{ font-family:"MyriadPro-Regular"; font-size: 14px; color:#FFF; text-align:center; font-style:normal;padding:0 10px 0 0;} 

#services_article .contenthover p span{ font-size:17px;}
#services_article .contenthover p .sec{ font-size:24px!important;}

 .align{ font-family:"MyriadPro-Regular"; font-size: 18px !important; color:#FFF !important; text-align:center!important; font-style:normal;padding:12px 10px 0 0;} 
 
 
 #services_article .hover-small-box{ width:159px; float:left; padding:0px 0; margin:0 9px 0px 0; min-height:145px; background:#242424; }
#services_article .hover-small-box p{font-family:"MyriadPro-Regular";  font-size: 14px; *font-size: 13px; color:#FFF; text-align:center; font-style:normal;  padding: 2px 7px 0 7px;}  

#services_article .small-box-txt
{
 margin-left: 2px !important;
  margin-right: 2px !important;
  margin-top: -4px !important;
 *margin-top: -5px !important;
 text-align: center !important;
}



.hover-sign{ width:87px; float:left; margin:10px 10px 0 35px; height:27px; background:url(images/hover-sign-up.jpg) no-repeat; }
.hover-sign:hover{ background-position:center -27px;}


#services_article .hover-small-box1{ width:159px; float:left; margin:0 0 9px 0; min-height:145px; background:#242424; }
#services_article .hover-small-box1 p{font-family:"MyriadPro-Regular"; font-size: 14px; color:#FFF; text-align:center; font-style:normal;padding:12px 0 0 0;  min-height:145px; }
.small-box-txt{ text-align:left; margin:10px 0 0 10px !important; padding:0 !important;} 

#services_article .hoverbox-01{ width:327px; background:#242424; float:left; margin:0 0 9px 0; min-height:145px; }

#services_article .hoverbox-01 p{ font-family:"MyriadPro-Regular"; font-size: 14px; color:#FFF; text-align:right; font-style:normal;padding:0 10px 0 0;} 

.small-box-txt-1{ text-align:center !important; margin:0 0 0 0 !important; padding:0 !important;}
.small-box-txt-2{  margin:30px 0 0 0px !important; padding:0 !important; text-align:center !important;}
.small-box-txt-3{  margin:5px 7px 0 7px !important; padding:0 !important; text-align:center !important;}
.small-box-txt-4{ text-align:center !important; margin:18px 0 0 0 !important; padding:0 !important;}
.small-box-txt-5{ text-align:center !important; margin:30px 0 0 0 !important; padding:0 !important;}
.small-box-txt-6{
text-align:right !important;
}
.help{ font-size:24px;}
.free{ font-size:24px; color:#f9d654;}

.hover-read{ width:87px; float:left; margin:5px 0 0 115px; height:27px; background:url(../image/read-more.jpg) no-repeat; }
.hover-read:hover{ background-position:center -27px;}

.clear{ clear:both;}



/**** add by vs*/
/*Product Page Start Here*/



.vmware_box_top{
width:100%;
height:auto;
margin:9px 0 0 0;
float:left;
text-align:center;
}

.vm_boxone{
width:322px;
height:auto;
float:left;
}

.vm_box_two{
width:223px;
height:227px;
float:left;
margin:0 0 0 9px;
}

.vm_boxthree{
width:223px;
height:auto;
float:right;
}

.vm_boxlarge{
width:97px;
height:227px;
float:left;
margin:0 0 0 9px;
overflow:hidden;
}

.vw_boxtop{
width:100%;
height:auto;
float:left;
}

.vw_boxbottom{
width:100%;
height:auto;
float:left;
margin:9px 0 0 0;
}

.vm_boxsmall{
width:107px;
height:109px;
float:left;
}

.vw_boxmedium{
width:206px;
height:109px;
float:left;
}


.green{
background:#3ec4a3;
}
.blue{
background:#005c85;
}

.skyblue{
background:#43b3e5;
}

.yellow{
background:#f9d654;
}
.grey{
background:#d3d3d3;
}


.floating{
float:right !important;
}


.vmware_box_bottom{
width:100%;
height:auto;
text-align:center;
margin:9px 0 0 0;
font-size:14px;
float:left;
}

.vmware_box_bottom div{
width:243px;
height:109px;
margin:0 9px 0 0;
float:left;
}



/*FAQ Page Start Here*/
.faq-heading{   background: none repeat scroll 0 0 #005B84;
    color: #FFFFFF;
    float: left;
    font-size: 18px;
    height: auto;
    padding: 20px 0;
    width: 1000px;
	text-align:center;	
}
.faq-left-nav{ width:223px; float:left; margin:10px 8px 0 0;min-height:232px; background:#f9d654; padding:8px 0;}

.faq-left-nav ul{ margin:0 0 0 10px; padding:0; list-style-type:none;}
 .faq-left-nav ul li{ display:block; margin:0;padding:0 0 0 16px; color:#000; line-height:18px;}
 .faq-tech-forum{ width:769px; float:left; margin:10px 0 0 0; font-size:26px; padding:25px 0; background:#34A0D1; text-align:center; color:#fff;} 
 .faq-tech-forum1{ width:759px; float:left; margin:6px 0 0 0; font-size:13px; padding:10px 0; background:#D3D3D3; text-align:justify;padding:5px; color:#333333;} 
.faq-tech-forum1 p
{
padding:11px 5px ;
text-align:justify;
}
.faq-general{   background: none repeat scroll 0 0 #005B84;
    color: #FFFFFF;
    float: left;
    font-size: 18px;
    height: auto;
    padding: 5px 0;
    width: 995px;
	margin:10px 0 0 0;
	text-align:center;	
} 

.faq-ques{ width:995px; float:left; background:#f9d654;color:#333333; padding:0 0 0 5px; line-height:20px; }
.faq-ques1{ width:995px; float:left; background:#f9d654;color:#333333; padding:0 0 0 5px; height:20px; }
#faq-ans{ width:995px; float:left; background:#35aa8d;color:#fff; padding:0 0 0 5px; line-height:20px;}

.faqmenu a
{
color:#313131;
text-decoration:none;
display: block !important;
}
.faqmenu a:hover
{
color:#35AA8D;

}

/*Network Monitoring Start Here*/


.network_main{
width:100%;
height:auto;
float:left;
margin:9px 0 0 0;
}

.net_boxone{
width:209px;
height:373px;
float:left;
}
.net_boxone p{
padding: 59px 5px;
text-align:center;
font-size: 14px;
}
.net_boxone a
{
background: none repeat scroll 0 0 #005B84;
    color: #FFFFFF;

    padding: 8px;
    text-decoration: none;
font-family: arial,helvetica,serif;
font-weight:bold;
font-size: 12px;
}
.net_boxone a:hover
{
background:#036896;
}

.net_boxtwo{
width:299px;
height:auto;
margin:0 0 0 9px;
float:left;
}

.net_box_top{
width:100%;
height:182px;
float:left;
}
.net_box_top p
{
padding: 74px 32px;
text-align:center;
font-size: 14px;
}

.net_box_bottom{
width:100%;
height:182px;
margin:9px 0 0 0;
float:left;
}

.net_box_bottom p
{
padding: 65px 32px;
text-align:center;
font-size: 14px;
}
.net_boxthree{
width:474px;
height:373px;
float:right;
font-family: 'MyriadPro-Regular';
font-size: 14px;
color:#fff;
}

.net_boxthree h1{
font-family: arial,helvetica,serif;
    font-size: 18px;
    font-weight: normal;
    padding: 10px 0 10px 20px;
	}

.net_boxthree p{
padding:10px;
font-size:12px !important;
font-family:Arial, Helvetica, sans-serif;
line-height:20px;
}

.net_boxthree ul{
margin:0 20px;
}

.net_boxthree ul li{
background:url(images/white_square.png) no-repeat 0 4px;
padding:0 0 6px 15px;
text-align: justify;
}
.protective
{
float: left;
    font-size: 14px;
    height: auto;
    margin: 9px 0 0;
    text-align: center;
    width: 100%;
	background:#3ec4a3;
	}

.analisys{/*width:1000px; margin:0 auto;background:#3ec4a3; height:600px;
*/}
.analisys-left{ width:505px; float:left; margin:25px 0 0 12px;}
.analisys-right{ width:450px; float:right; margin:25px 6px 0 12px; text-align: left;}
.analisys-right-top{ width:400px; font-weight:normal; float:right; line-height:20px; font-size:12px; font-family:Arial, Helvetica, sans-serif; background:#005c85; color:#FFF; padding:10px 8px 10px 10px;}
.analisys-right-top01{ width:400px; float:right; line-height:20px; font-size:12px; 
font-family:Arial, Helvetica, sans-serif;  color:#fff; padding:10px 8px 10px 10px; font-weight:normal; background:#43b3e5; margin:10px 0 0 0; }

.analisys h1{ font-size:18px;
font-family:Arial, Helvetica, sans-serif; color:#333;; padding:0 0 0 30px} 
 
.analisys-right-top2{ width:400px; font-weight:normal; float:right; line-height:20px; font-size:12px; 
font-family:Arial, Helvetica, sans-serif; background:#f9d654; color:#333; padding:10px 8px 10px 10px; margin:10px 0 0 0;}
 
/*Network Monitoring Ends Here*/


 /*Testimonials Start Here*/

.testimonials_wrapper{
width:100%;
height:auto;
background:#f9d654;
padding:20px 0 30px 0;
float:left;
}


.testimonials{
width:403px;
height:auto;
background:#000;
padding:0 20px;
text-align:justify;
line-height:18px;
color:#fff;
float:left;
}

.testi_left{
width:443px;
height:auto;
float:left;
margin:20px 0 0 30px;
}
.author_left {
    font-weight: bold;
    margin: -30px 120px 20px 20px;
    text-align: right;
	font-size: 13px;
}
.author_right {
    font-weight: bold;
    margin: -30px 20px 20px 120px;
    text-align: left;
	font-size: 13px;
}
.testi_right{
width:443px;
height:auto;
float:right;
margin:40px 30px 0 0;

}

.rounded{
width:100%;
height:auto;
float:left;
margin:0px;
padding:0px;
}

.rounded img{
vertical-align:top;
}

/****amazon****/
.aws1{
	background-color:#3ec4a3;
	padding:10px;
	width:350px;
	float:left;
	margin-right:10px;
	height:85px;
	text-align:center;
	color:#fff;
}
.aws1 p
{
padding:15px 0;
}

.aws1 a
{
color:#fff;
text-decoration:underline;
}
.aws1 a:hover
{

text-decoration:underline;
}
.aws2{
	background-color:#43b3e5;
	padding:10px;
	width:350px;
		float:left;
			margin-right:10px;
				height:85px;
				text-align:center;
				color:#fff;
}
.aws2 p
{
padding:15px 0;
}

.aws2 a
{
color:#fff;
text-decoration:underline;
}
.aws2 a:hover
{

text-decoration:underline;
}
.aws3{
	background-color:#d3d3d3;
	padding:10px;
	width:200px;
		float:left;
			margin:10px 0 0 0px;
				height:85px;
				text-align:center;
				color:#313131;

}
.aws3 p
{
padding:15px 0;
}

.aws3 a
{
color:#313131;
text-decoration:underline;
}
.aws3 a:hover
{

text-decoration:underline;
}
.aws4{
	background-color:#f9d654;
	padding:10px;
	width:500px;
		float:left;
			margin:10px 0 0 10px;
				height:85px;
				text-align:center;
				color:#313131;
}
.aws4 p
{
padding:15px 0;
}
.aws4 a
{
color:#313131;
text-decoration:underline;
}
.aws4 a:hover
{

text-decoration:underline;
}
.aws5{
	background-color:#005c85;
	padding:10px;
	width:220px;
		float:left;
		height:200px;
		color:#FFFFFF;
		text-align:center;
}
.aws5 p
{
padding:60px 0;
}
.aws5 a
{
color:#fff;
text-decoration:underline;
}
.aws5 a:hover
{

text-decoration:underline;
}
.cloud_rowtwoleft{
clear:both;
	width:760px;
height:auto;
float:left;
margin:9px 0 0 0;

}
.cloud_rowtworight{
	width:240px;
height:auto;
float:left;
margin:9px 0 0 0;
}

/**** network switches and router****/
.router{
width:100%;
height:auto;
float:left;
background:#005B84;
color:#fff;
text-align:center;
margin:9px 0 0 0;
padding:10px 0;
}
.router h1
{
font-size:18px;
}
.router h1 a
{
color:#fff;
text-decoration:underline;
}
.router p
{
font-size:14px;
}
.customers_right_router{
width:300px;
height:auto;
float:right;
margin:20px 9px 0 0;
background:#43B3E5;
padding:10px 0;
color:#fff;
}
.router_box_bottom{
width:100%;
height:auto;
text-align:center;
margin:9px 0 0 0;
font-size:16px;
float:left;
font-family:"MyriadPro-Regular";
}

.router_box_bottom div{
width:243px;
height:109px;
margin:0 9px 0 0;
float:left;
}
.router_box_bottom .yellow p
{
color:#313131;
padding:45px 0;
}
.router_box_bottom .grey p
{
color:#313131;
padding:45px 0;
}
.router_box_bottom .blue p
{
color:#fff;
padding:45px 0;
}
.router_box_bottom .skyblue1
{
height:50px;
margin:0 0 9px 0;
background:#43B3E5;
color:#fff;
}
.router_box_bottom .skyblue2
{
height:50px;
background:#43B3E5;
color:#fff;
}
.router_box_bottom .skyblue1 p
{
padding:16px 0;
}
.router_box_bottom .skyblue2 p
{
padding:16px 0;
}
/****** Contact us ******/
.contact_wrapper_main {
   
    float: left;
    font-family: Arial,Helvetica,sans-serif;
    height: auto;
    margin: 18px 0 0;
    padding: 11px 0;
    width: 100%;
}
.window-sol{ width:960px; float:left; margin:0 0 10px 0;}

.inner-area p { 
    line-height: 18px;
    margin: 5px 0 5px 0;
    text-align: justify;
    width: 100%;
	min-height:0px;
	}
.form_title {
    background: none repeat scroll 0 0 #005B84;
    color: #FFFFFF;
    font-size: 16px;
    font-weight:normal;
    padding: 10px !important;
	font-family: 'MyriadPro-Regular';

}
#contactform td {
    vertical-align: middle;
	 padding: 5px;
}
sup
{
color:red;
}

/*form-page start here*/
.form-area{ width:100%; margin:0; float:left; background:#005b84; font-family:"MyriadPro-Regular";}
.form-main{ width:920px; float:left; margin:20px 40px 20px 40px;}
div.printfriendly
{
margin:0px !important;	
}
div.printfriendly a, div.printfriendly a:link, div.printfriendly a:visited
{
 color: #F9D654 !important;
    font-family: arial,helvetica,serif !important;
    font-size: 12px !important;
    font-weight: bold !important;
}
.form-main .back
{
float:right;
margin-right: 10px;
}
.form-main .back input[type="submit"]{
background: none repeat scroll 0 0 #F9D654;
    border: medium none;
    color: #080808;
    cursor: pointer;
    margin: 0 auto;
    outline: medium none;
    padding: 5px 12px;
    text-align: center;
    font-family: arial,helvetica,serif;
    font-size: 12px;
    font-weight: bold;
    width: 70px;
    height: 25px;
}
.form-main .back input[type="submit"]:hover
{
  background: none repeat scroll 0 0 #F2CE4B; 
}
.form-main .logoutbtn a {
 background: none repeat scroll 0 0 #F9D654;
    border: medium none;
    color: #080808;
   
    float: right;
    font-family: arial,helvetica,serif;
    font-size: 12px;
    font-weight: bold;
    text-decoration: none;
	 padding: 5px 12px;
}
.form-main .logoutbtn a:hover{
  background: none repeat scroll 0 0 #F2CE4B; 
}
.form-left{ width:460px; float:left; margin:0 0 0px 0;}
.form-right{ width:459px; float:right; margin:0;}
.from-inner-left{ width:459px; margin:0 0 14px 0; float:left}
.form-txt{ width:247px; float:left; margin:0; font-size:16px; color:#FFF;text-align:left;}
.form-txtlast{ width:920px; float:left; margin:0; font-size:16px; color:#FFF;text-align:left;}
.form-box{ width:180px; float:left; margin:0; vertical-align:top;}
.check_content{
width:212px;
height:auto;
float:right;
}
.form-box span{float:left; margin:9px 0 0 5px; *margin:12px 0 0 5px; color:#fff;}
.form-box input[type="text"]{ width:180px; float:left; margin:0; padding:0px 0 0px 3px; border:none; color:#666;  height:27px; }

.form-box input[type="password"]{ width:180px; float:left; margin:0; padding:0px 0 0px 3px; border:none; color:#666;  height:27px; }
 
.form-box select{ width:182px; float:left; margin:0; padding:3px 3px 3px 3px; border:none; color:#666;  height:27px; }

.form-box textarea{ width:182px; height:100px; float:left; margin:0; padding:0px 3px 0px 3px; border:none; color:#666;  }

.form-box input[type="checkbox"]{ float:left; margin:9px 0 10px 0; padding:0; border:none; outline:none; color:#666;  }

.sub{ width:920px; margin:15px 0; *padding:0 0 20px 0 float:left;}
.submit{ width:64px; margin:20px auto 0 auto; }
.submit input[ type="submit"]{ width:64px; margin:0 auto; padding:4px; background:#f9d654; color:#080808; text-align:center; border:none; outline:none; cursor:pointer; }
.submit input[ type="button"]{ width:64px; margin:0 auto; padding:4px; background:#f9d654; color:#080808; text-align:center; border:none; outline:none; cursor:pointer; font-family: arial,helvetica,serif; font-weight:bold;}
 
.form-box input[type="submit"] {
    background: none repeat scroll 0 0 #F9D654;
    border: medium none;
    color: #080808;
    cursor: pointer;
    margin: 0 auto;
    outline: medium none;
    padding: 4px;
    text-align: center;
    width: 64px;
	 font-family: arial,helvetica,serif; font-weight:bold;
}
.form-box input[type="reset"] {
    background: none repeat scroll 0 0 #F9D654;
    border: medium none;
    color: #080808;
    cursor: pointer;
    margin: 0 0 0 10px;
    outline: medium none;
    padding: 4px;
    text-align: center;
    width: 64px;
	 font-family: arial,helvetica,serif; font-weight:bold;
}
.form-txtlast #msg_box
{
  font-size: 12px;
    font-style: italic;
    font-weight: normal;
    margin-left: -33px;
    margin-right: 14px;
    padding-bottom: 13px;
    text-align: justify;
	}
.contact_top{
width:403px;
height:auto;
float:right;

line-height:18px;
color:#fff;
}

.contact_top a{
color:#fff;
text-decoration:none;
}

.contact_top a:hover{
color:#f9d654;
text-decoration:none;
}

.form-right h1{
font-size:16px;
font-weight:bold;
color:#f9d654;
}

.contact_detail{
width:100%;
height:auto;
float:left;
margin:10px 0 0 0;
}

.contact_main{
width:100%;
height:auto;
float:left;
padding:0 0 10px 0;
}

.contact_deatial_left{
width:124px;
height:auto;
float:left;
}

.contact_deatial_right{
width:124px;
height:auto;
float:left;
}

.contact_bottom{
width:403px;
height:auto;
float:right;
line-height:18px;
padding:0 0 20px 0;
color:#fff;
 text-align: justify;
  font-style: italic;
}

.contact_bottom td{
padding:2px 0;
}

.contact_bottom a{
color:#fff;
text-decoration:none;
}

.contact_bottom a:hover{
color:#f9d654;
text-decoration:none;
}
/*Porposal Start here*/


.proposal_top{
width:980px;
height:auto;
float:left;
padding:10px;
background:#005c85;
color:#fff;
}

.proposal_top_left {
    float: left;
    height: auto;
    margin: 5px 0 0 10px;
    text-align: justify;
    width: 764px;
}
.proposal_top_right {
    float: left;
    height: auto;
    margin: 0 0 0 6px;
    text-align: center;
    width: 200px;
}
.proposal_top_right a
{
background: none repeat scroll 0 0 #F9D654;
    border: medium none;
    color: #080808;
    cursor: pointer;
    font-family: arial,helvetica,serif;
    font-weight: bold;
    margin: 0 auto;
    outline: medium none;
    padding: 8px 18px;
    text-align: center;
	text-decoration:none;
	font-size:14px;
  
}
.proposal_top_right a:hover
{
background: none repeat scroll 0 0 #F2CE4B;
}



.proposal_top_right form input[type="submit"]{
  background: none repeat scroll 0 0 #F9D654;
    border: medium none;
    color: #000;
    cursor: pointer;
    font-family: arial,helvetica,serif;
    font-size: 12px;
    font-weight: normal;
   
	padding: 8px 18px;
    text-transform: uppercase;
	 font-weight: bold;
    
}
.proposal_top_right form input[type="submit"]:hover{
background: none repeat scroll 0 0 #F2CE4B;
}


.recommendation_main{
width:100%;
height:auto;
float:left;
padding:10px 0;
background:#3ec4a3;
margin:10px 0 0 0;
}

.recommendation_left{
width:312px;
height:auto;
float:left;
margin:5px 0 0 10px;
}

.recommendation_right{
width:646px;
height:auto;
float:left;
margin:0 0 0 10px;
text-align:justify;
}
.recommendation_right a
{
color:#000;

text-decoration:underline;
}
.recommendation_right a:hover
{

text-decoration:underline;
}
.recommendation_services{
width:100%;
height:auto;
float:left;
}

.r_s_left{
width:790px;
height:auto;
float:left;
}

.r_s_right{
width:203px;
height:212px;
background:url(images/value.jpg) no-repeat 15px 40px #005c85;
margin:10px 0 0 0;
font-family:Arial, Helvetica, sans-serif;
font-weight:bold;
color:#fff;
float:right;
}

.r_s_right a{
color:#fff;
text-decoration:underline;
}
.r_s_right h2
{
font-size: 18px;
    padding: 0 0 10px;
    text-align: center;
}
.r_s_right ul{
font-size:10px; 
margin: 10px 0 10px 29px;
}

.r_s_right ul li{
background:url(images/p_bullet.gif) no-repeat 3px 5px;
padding:2px 0 0 10px;
} 

.r_s_left_content{
width:100%;
height:auto;
margin:10px 0 0 0;
float:left;
}

.subscription{
width:389px;
height:91px;
background:url(images/best.jpg) no-repeat 12px 0 #f9d654;
float:left;
text-align:center;
font-family:Arial, Helvetica, sans-serif;
font-weight:bold;
padding:10px 0 0 0;
}
.subscription a{
color:#000;
text-decoration:underline;
}
.security{
width:390px;
height:91px;
background:url(images/better.jpg) no-repeat 12px 0 #3ec4a3;
float:right;
padding:10px 0 0 0;
font-family:Arial, Helvetica, sans-serif;
font-weight:bold;
text-align:center;
}

.security a{
color:#000;
text-decoration:underline;
}

.demand{
width:475px;
height:101px;
background:url(images/good.jpg) no-repeat 12px 0 #43b3e5;
float:left;
font-family:Arial, Helvetica, sans-serif;
font-weight:bold;
text-align:center;
}
.demand a{
color:#000;
text-decoration:underline;
}

.time{
width:303px;
height:91px;
float:right;
background:url(images/must.jpg) no-repeat 12px 0 #f9d654;
font-family:Arial, Helvetica, sans-serif;
font-weight:bold;
padding:10px 0 0 0;
text-align:center;
}
.time a{
color:#000;
text-decoration:underline;
}




/*Porposal Ends here*/
/**** access report start here****/
.customers_wrapper_main_access{
    background: none repeat scroll 0 0 #005B84;
    float: left;
    font-family: Arial,Helvetica,sans-serif;
    height: auto;
    margin: 18px 0 0;
    padding: 11px 0;
    width: 100%;
}
.customers_wrapper_main_access .access_report
{
	text-align:center;
	padding:20px 0;
	margin:0;
}

.customers_wrapper_main_access .access_report td
{
	
	padding:2px;
   color: #005B84;
}
.customers_wrapper_main_access .access_report td a
{
	
	text-decoration:none;
   color: #005B84;
}

.customers_wrapper_main_access .access_report input[ type="text"]{
border:1px solid #ccc;
padding:4px;
}
.customers_wrapper_main_access .access_report input[ type="password"]{
border:1px solid #ccc;
padding:4px;
}
.customers_wrapper_main_access .access_report input[type="submit"] {
    background: none repeat scroll 0 0 #005B84;
    border: medium none;
    color: #FFFFFF;
    cursor: pointer;
    font-family: arial,helvetica,serif;
    font-weight: bold;
    margin: 4px auto;
    outline: medium none;
    padding: 4px;
    text-align: center;
    width: 64px;
}
.customers_wrapper_main_access .access_report input[type="submit"]:hover{
background:#036896;
}
/*access report Ends here*/

/*Club Page Start Here*/


.innerpage_title{
width:100%;
height:auto;
float:left;
}


.innerpage_title h1 {
    background-color: #005B84;
    color: #FFFFFF;
    display: block;
    font-family: 'MyriadPro-Regular';
    font-size: 18px;
    font-weight: normal;
    padding: 20px;
    text-align: center;
}

.club_main{
width:100%;
height:auto;
font-size:14px;
line-height:20px;
text-align:justify;
font-family:Arial, Helvetica, sans-serif;
float:left;
}

.club_top{
width:100%;
height:auto;
float:left;
text-align:center;
}

.club_bottom{
width:100%;
height:auto;
float:left;
margin:10px 0 0 0;
}



.club_left{
width:625px;
height:auto;
float:left;
}

.club_right{
width:363px;
height:auto;
float:right;
}

.club_join{
width:595px;
height:296px;
float:left;
padding:15px;
color:#fff;
font-family: myriadpro-regular;
font-size:16px;
}
.club_join h1
{
color: #FFFFFF;
    font-family: Arial,Helvetica,sans-serif;
    font-size: 18px;
    font-weight: normal;
    padding: 0px 0 5px 0px;
}

.club_join ul li{
padding:2px 0 0 10px;
background:url(images/club_bullet2.png) no-repeat 0 8px;
}
.club_main p{
padding:4px 0 0 0;
}
.club_member{
width:333px;
height:296px;
float:left;
padding:15px;
color:#000;
font-size:16px;
font-family: myriadpro-regular;
}
.club_member h1
{
color: #000;
    font-family: Arial,Helvetica,sans-serif;
    font-size: 18px;
    font-weight: normal;
    padding: 0px 0 5px 0px;
}
.club_member ul li{
background:url(images/club_bullet1.png) no-repeat 0 8px;
padding:0 0 0 10px;

}

.monthly_main{
width:306px;
height:auto;
text-align:center;
float:left;
font-family: myriadpro-regular;
font-size:16px;
color:#fff;
}

.monthly{
width:100%;
height:80px;
float:left;
margin:10px 0 0 0;
padding:30px 0 0 0;
font-family: myriadpro-regular;
font-size:16px;
color:#fff;
}

.club_mail{
width:181px;
height:230px;
float:left;
margin:10px 0 0 10px;

font-family: myriadpro-regular;
font-size:16px;
color:#000;

}
.yellow p {
    padding: 105px 0;
	}
.club_access{
width:301px;
height:auto;
float:left;
margin:0 0 0 10px;
}

.club{
width:594px;
height:246px;
float:left;
text-align:center;
font-family:Arial, Helvetica, sans-serif;
line-height:20px;
}

.club h1{
font-size:60px;
font-weight:bold;
color:#ffff33;
padding:40px 0 10px; 0;
display:block;
}
.club h2{
font-size:30px;
color:#ffff33;
padding:10px 0 10px 0;
margin:0px;
display:block;
}



.club a{
font-weight:bold;
text-decoration:none;
color:#000;
background:#f5d84c;
width:150px;
height:50px;
display:block;
padding:8px 0 0 0;
margin:auto;
}




/*Club Page Ends Here*/

.footer_wrapper_bottom{
width:1000px;
margin:auto;
}

.footer_bottom{
width:100%;
height:auto;
color:#727070;
float:left;
margin:20px 0 0 0;
}
.footer_bottom a{
color:#727070;
text-decoration:none;
}

.footer_bottom a:hover{
color:#ada784;
text-decoration:none;
}

.footer_bottom ul{
margin:10px 0 0 0;
padding:0px;
}

.footer_bottom ul li{
display:block;
padding:5px 0;
}

.footer_bottom  h1{
font-size:18px;
color:#f9d654;
}

.footer_bottom ul li ul{
margin:0px 0 0 10px;
}

.footer_bottom ul li ul li{
padding:5px 0;
float:none;
}

.footer_bottom ul li ul.sitemap li{
float:left;

width:400px;
}

.footer_title{
color:#ada784;
font-weight:bold;
}

#quicklink td{
padding:4px 0;
}

/*Scan Server Start Here*/


.scan_server{
font-family:Arial, Helvetica, sans-serif;
margin:20px 0 0 0;
}

.scan_server tr.rowodd{
background:#e0e0e0;
padding:5px 0;
}
.scan_server tr{
background:#fff;
}

.scan_server tr td.scan_title{
background:#e0e0e0;
font-size:18px;
font-weight:bold;
color:#000;
padding:10px 5px;
}

.scan_server tr td{
padding:5px;
}


.scan_server tr td form input[type="submit"]{
  background: none repeat scroll 0 0 #005B84;
    border: medium none;
    color: #FFFFFF;
    cursor: pointer;
    font-family: arial,helvetica,serif;
    font-size: 12px;
    font-weight: normal;
    height: 25px;
  
    text-transform: uppercase;
    width: 62px;
}
.scan_server tr td form input[type="submit"]:hover{
background:#036896;
}


.scan_server tr td form input[type="button"] {
    background: none repeat scroll 0 0 #B7B7B7;
    border: medium none;
    color: #000000;
    font-family: arial,helvetica,serif;
    font-size: 12px;
    font-weight: normal;
    height: 25px;
    text-transform: uppercase;
    width: 62px;
}

.scan_server tr td form input[type="button"]:hover{
background:#cccccc;
}


/*Scan Server Ends Here*/
 
