<?php
/**
 * Template name:Access Inspection Report page

 */

get_header();
?>
 <!--Main Container Start Here-->
  <section id="content_wrapper_main">
    <section class="content_wrapper">
	<section class="customers_wrapper_main_access">
    <section class="access_report">

	<?php
	 $err=$_GET['msg'];
	 if($err !=""){
	  $msg ="Email and password not match. please try again.";
	 }
	?>
	
	<form method="post" name="loginform" action="<?php bloginfo('url');?>/checklogin.php">
		<table width="350" cellspacing="0" cellpadding="0" border="0" align="center" class="access-inspection-reporttb" style="background:#ffffff;border:1px solid #005B84;margin:5px auto;">
			<tbody>
			
			<tr><td style="color:red;"> <?php echo $msg;?></td></tr>
			<tr>
				<td align="center" style="padding:8px 4px;">
					<table cellspacing="0" cellpadding="4" border="0">
						<tbody><tr>
							<td width="100">Login Name:</td>
							<td width="150" align="right"><input type="text" style="width:150px;" value="" id="login" name="login"></td>
							
						</tr>
						<tr>
							<td>Password:</td>
							<td align="right"><input type="password" style="width:150px;" value="" id="pass" name="pass"></td>
						</tr>
						<tr>
						<td>&nbsp;</td>
							<td>
							<input type="submit" value="Login" id="logclick" name="logclick">
							</td>
						</tr>
						<tr>
						<td>&nbsp;</td>
							<td><a href="#">Retrieve Password</a>
							</td>
						</tr>
					</tbody></table>
				</td>
			</tr>
		</tbody></table>
		
	</form>
      </section>
     </section>
      </section>
  </section>
  <!--Main Container Ends Here-->

	<?php get_footer(); ?>
</div><!--wrapper ends here -->